/**
 * @license
 * Copyright 2019 Google LLC
 * SPDX-License-Identifier: BSD-3-Clause
 */

import {LitElement, html,CSSResultGroup} from 'lit';
import {customElement, property, state} from 'lit/decorators.js';
import  "./components/dev-console-products"
import "./components/dev-console-product-details"
import { globalStyles } from './styles';
import { gridSvg } from './assets/svg-ts/grid';
/**
 * @fires count-changed - Indicates when the count changes
 * @slot - This element has a slot
 * @csspart button - The button
 */
@customElement('dev-console-widget')
export class DevConsoleWidget extends LitElement {
 static override styles?: CSSResultGroup | undefined = [globalStyles];
  override connectedCallback(): void {
    super.connectedCallback()
    this.fetchData();
  }

  @property()
  iconHeight = '32px'

  @property()
  iconWidth = '32px'

  @property()
  iconColor = 'white'

  @state()
  activeProductKey = 'apex'

  @state()
  productDetailsMap: any = {};

  async fetchData(){
    const res = await fetch(`./products-mock-jsons/${this.activeProductKey}.json`);
    const data = await res.json();
    
    this.productDetailsMap = {...this.productDetailsMap, [this.activeProductKey]: data}
  }
  override render() {
    return html`
      <div class="h-full flex items-center cursor-pointer group font-sans">
        <div style="color: ${this.iconColor}; width: ${this.iconWidth}; height: ${this.iconWidth};">
        ${gridSvg}
        </div>
        <div class="absolute z-20 left-0 top-full w-full shadow-md cursor-default bg-white hidden group-hover:block">
          <div class="grid grid-flow-col grid-cols-1 lg:grid-cols-4 gap-0 divide-x text-sm"  @productSelect=${this._selectListener}>
            <dev-console-products class="col-span-1 py-6 h-widget-dropdown overflow-y-auto"></dev-console-products>
            ${this.productDetailsMap[this.activeProductKey] ? (
              html`
                <dev-console-product-details class="col-span-3 py-6 px-8 h-widget-dropdown overflow-y-auto" .productDetails=${this.productDetailsMap[this.activeProductKey]}></dev-console-product-details>
              `
            ):(
              html`
                <span>Loading...</span>
              `
            )}
          </div>
        </div>
      </div>
    `;
  }

  private _selectListener(e:CustomEvent){
    this.activeProductKey = e.detail.uniqueKey;
    if(!this.productDetailsMap[this.activeProductKey]){
      this.fetchData()
    } 
  }
}

declare global {
  interface HTMLElementTagNameMap {
    'dev-console-widget': DevConsoleWidget;
  }
}


// .console-widget {
//   font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", "Roboto", "Oxygen",
// "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue",
// sans-serif;
// display: flex;
// align-items: center;
// cursor: pointer;
// height: 100%;
// }
// .console-widget:hover .console-widget-dropdown-menu {
//   display: block;
// }
// .console-widget-menu-container {
//   min-height: auto;
//   display: flex;
//   align-items: start;
//   background-color: rgb(255 255 255);
//   strong {
//     color: rgb(0 0 0);
//   }
//   > * {
//     margin-left: 2rem;
//     height: 552px;
//     overflow-y: auto;
//   }
//   > *:first-child {
//     margin-left: 0rem;
//     border-right: 1px solid rgba(152, 162, 179, 0.3);
//   }
// }